==> ap_common-0.8.0.tar.gz: lib/resources/ap_icon.dart <==
import 'package:flutter/material.dart';

class ApIcon {
  static const String FILLED = 'filled';
  static const String OUTLINED = 'outlined';

  static String code = ApIcon.OUTLINED;

  static IconData get directionsBus {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.directions_bike;
      case ApIcon.OUTLINED:
      default:
        return Icons.directions_bike_outlined;
    }
  }

  static IconData get classIcon {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.class_;
      case ApIcon.OUTLINED:
      default:
        return Icons.class__outlined;
    }
  }

  static IconData get assignment {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.assignment;
      case ApIcon.OUTLINED:
      default:
        return Icons.assignment_outlined;
    }
  }

  static IconData get accountCircle {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.account_circle;
      case ApIcon.OUTLINED:
      default:
        return Icons.account_circle_outlined;
    }
  }

  static IconData get school {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.school;
      case ApIcon.OUTLINED:
      default:
        return Icons.school_outlined;
    }
  }

  static IconData get apps {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.apps;
      case ApIcon.OUTLINED:
      default:
        return Icons.apps_outlined;
    }
  }

  static IconData get calendarToday {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.calendar_today;
      case ApIcon.OUTLINED:
      default:
        return Icons.calendar_today_outlined;
    }
  }

  static get edit {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.edit;
      case ApIcon.OUTLINED:
      default:
        return Icons.edit_outlined;
    }
  }

  static get dateRange {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.date_range;
      case ApIcon.OUTLINED:
      default:
        return Icons.date_range_outlined;
    }
  }

  static get info {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.info;
      case ApIcon.OUTLINED:
      default:
        return Icons.info_outline;
    }
  }

  static get face {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.face;
      case ApIcon.OUTLINED:
      default:
        return Icons.face_outlined;
    }
  }

  static get settings {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.settings;
      case ApIcon.OUTLINED:
      default:
        return Icons.settings_outlined;
    }
  }

  static IconData get powerSettingsNew {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.power_settings_new;
      case ApIcon.OUTLINED:
      default:
        return Icons.power_settings_new_outlined;
    }
  }

  static get permIdentity {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.perm_identity;
      case ApIcon.OUTLINED:
      default:
        return Icons.perm_identity_outlined;
    }
  }

  static IconData get accessTime {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.access_time;
      case ApIcon.OUTLINED:
      default:
        return Icons.access_time_outlined;
    }
  }

  static IconData get keyboardArrowDown {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.keyboard_arrow_down;
      case ApIcon.OUTLINED:
      default:
        return Icons.keyboard_arrow_down_outlined;
    }
  }

  static get offlineBolt {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.offline_bolt;
      case ApIcon.OUTLINED:
      default:
        return Icons.offline_bolt_outlined;
    }
  }

  static IconData get error {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.error;
      case ApIcon.OUTLINED:
      default:
        return Icons.error_outline_outlined;
    }
  }

  static IconData get fiberNew {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.fiber_new;
      case ApIcon.OUTLINED:
      default:
        return Icons.fiber_new_outlined;
    }
  }

  static IconData get phone {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.phone;
      case ApIcon.OUTLINED:
      default:
        return Icons.phone_outlined;
    }
  }

  static IconData get codeIcon {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.code;
      case ApIcon.OUTLINED:
      default:
        return Icons.code_outlined;
    }
  }

  static IconData get cancel {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.cancel;
      case ApIcon.OUTLINED:
      default:
        return Icons.cancel_outlined;
    }
  }

  static IconData get check {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.check;
      case ApIcon.OUTLINED:
      default:
        return Icons.check_outlined;
    }
  }

  static IconData get arrowDropUp {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.arrow_drop_up;
      case ApIcon.OUTLINED:
      default:
        return Icons.arrow_drop_up_outlined;
    }
  }

  static IconData get arrowDropDown {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.arrow_drop_down;
      case ApIcon.OUTLINED:
      default:
        return Icons.arrow_drop_down_outlined;
    }
  }

  static IconData get chevronLeft {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.chevron_left;
      case ApIcon.OUTLINED:
      default:
        return Icons.chevron_left_outlined;
    }
  }

  static IconData get chevronRight {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.chevron_right;
      case ApIcon.OUTLINED:
      default:
        return Icons.chevron_right_outlined;
    }
  }

  static IconData get person {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.person;
      case ApIcon.OUTLINED:
      default:
        return Icons.person_outlined;
    }
  }

  static IconData get exitToApp {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.exit_to_app;
      case ApIcon.OUTLINED:
      default:
        return Icons.exit_to_app_outlined;
    }
  }

  static IconData get warning {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.warning;
      case ApIcon.OUTLINED:
      default:
        return Icons.warning_outlined;
    }
  }

  static IconData get folder {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.folder;
      case ApIcon.OUTLINED:
      default:
        return Icons.folder_outlined;
    }
  }

  static IconData get insertDriveFile {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.insert_drive_file;
      case ApIcon.OUTLINED:
      default:
        return Icons.insert_drive_file_outlined;
    }
  }

  static IconData get collectionsBookmark {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.collections_bookmark;
      case ApIcon.OUTLINED:
      default:
        return Icons.collections_bookmark_outlined;
    }
  }

  static IconData get accessibilityNew {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.accessibility_new;
      case ApIcon.OUTLINED:
      default:
        return Icons.accessibility_new;
    }
  }

  static IconData get monetizationOn {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.monetization_on;
      case ApIcon.OUTLINED:
      default:
        return Icons.monetization_on_outlined;
    }
  }

  static IconData get map {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.map;
      case ApIcon.OUTLINED:
      default:
        return Icons.map_outlined;
    }
  }

  static IconData get navigation {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.navigation;
      case ApIcon.OUTLINED:
      default:
        return Icons.navigation_outlined;
    }
  }

  static IconData get room {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.room;
      case ApIcon.OUTLINED:
      default:
        return Icons.room_outlined;
    }
  }

  static IconData get home {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.home;
      case ApIcon.OUTLINED:
      default:
        return Icons.home_outlined;
    }
  }
}

==> ap_common-0.9.0.tar.gz: lib/resources/ap_icon.dart <==
import 'package:flutter/material.dart';

class ApIcon {
  static const String FILLED = 'filled';
  static const String OUTLINED = 'outlined';

  static String code = ApIcon.OUTLINED;

  static IconData get directionsBus {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.directions_bus;
      case ApIcon.OUTLINED:
      default:
        return Icons.directions_bus_outlined;
    }
  }

  static IconData get classIcon {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.class_;
      case ApIcon.OUTLINED:
      default:
        return Icons.class__outlined;
    }
  }

  static IconData get assignment {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.assignment;
      case ApIcon.OUTLINED:
      default:
        return Icons.assignment_outlined;
    }
  }

  static IconData get accountCircle {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.account_circle;
      case ApIcon.OUTLINED:
      default:
        return Icons.account_circle_outlined;
    }
  }

  static IconData get school {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.school;
      case ApIcon.OUTLINED:
      default:
        return Icons.school_outlined;
    }
  }

  static IconData get apps {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.apps;
      case ApIcon.OUTLINED:
      default:
        return Icons.apps_outlined;
    }
  }

  static IconData get calendarToday {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.calendar_today;
      case ApIcon.OUTLINED:
      default:
        return Icons.calendar_today_outlined;
    }
  }

  static get edit {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.edit;
      case ApIcon.OUTLINED:
      default:
        return Icons.edit_outlined;
    }
  }

  static get dateRange {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.date_range;
      case ApIcon.OUTLINED:
      default:
        return Icons.date_range_outlined;
    }
  }

  static get info {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.info;
      case ApIcon.OUTLINED:
      default:
        return Icons.info_outline;
    }
  }

  static get face {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.face;
      case ApIcon.OUTLINED:
      default:
        return Icons.face_outlined;
    }
  }

  static get settings {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.settings;
      case ApIcon.OUTLINED:
      default:
        return Icons.settings_outlined;
    }
  }

  static IconData get powerSettingsNew {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.power_settings_new;
      case ApIcon.OUTLINED:
      default:
        return Icons.power_settings_new_outlined;
    }
  }

  static get permIdentity {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.perm_identity;
      case ApIcon.OUTLINED:
      default:
        return Icons.perm_identity_outlined;
    }
  }

  static IconData get accessTime {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.access_time;
      case ApIcon.OUTLINED:
      default:
        return Icons.access_time_outlined;
    }
  }

  static IconData get keyboardArrowDown {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.keyboard_arrow_down;
      case ApIcon.OUTLINED:
      default:
        return Icons.keyboard_arrow_down_outlined;
    }
  }

  static get offlineBolt {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.offline_bolt;
      case ApIcon.OUTLINED:
      default:
        return Icons.offline_bolt_outlined;
    }
  }

  static IconData get error {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.error;
      case ApIcon.OUTLINED:
      default:
        return Icons.error_outline_outlined;
    }
  }

  static IconData get fiberNew {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.fiber_new;
      case ApIcon.OUTLINED:
      default:
        return Icons.fiber_new_outlined;
    }
  }

  static IconData get phone {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.phone;
      case ApIcon.OUTLINED:
      default:
        return Icons.phone_outlined;
    }
  }

  static IconData get codeIcon {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.code;
      case ApIcon.OUTLINED:
      default:
        return Icons.code_outlined;
    }
  }

  static IconData get cancel {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.cancel;
      case ApIcon.OUTLINED:
      default:
        return Icons.cancel_outlined;
    }
  }

  static IconData get check {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.check;
      case ApIcon.OUTLINED:
      default:
        return Icons.check_outlined;
    }
  }

  static IconData get arrowDropUp {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.arrow_drop_up;
      case ApIcon.OUTLINED:
      default:
        return Icons.arrow_drop_up_outlined;
    }
  }

  static IconData get arrowDropDown {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.arrow_drop_down;
      case ApIcon.OUTLINED:
      default:
        return Icons.arrow_drop_down_outlined;
    }
  }

  static IconData get chevronLeft {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.chevron_left;
      case ApIcon.OUTLINED:
      default:
        return Icons.chevron_left_outlined;
    }
  }

  static IconData get chevronRight {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.chevron_right;
      case ApIcon.OUTLINED:
      default:
        return Icons.chevron_right_outlined;
    }
  }

  static IconData get person {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.person;
      case ApIcon.OUTLINED:
      default:
        return Icons.person_outlined;
    }
  }

  static IconData get exitToApp {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.exit_to_app;
      case ApIcon.OUTLINED:
      default:
        return Icons.exit_to_app_outlined;
    }
  }

  static IconData get warning {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.warning;
      case ApIcon.OUTLINED:
      default:
        return Icons.warning_outlined;
    }
  }

  static IconData get folder {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.folder;
      case ApIcon.OUTLINED:
      default:
        return Icons.folder_outlined;
    }
  }

  static IconData get insertDriveFile {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.insert_drive_file;
      case ApIcon.OUTLINED:
      default:
        return Icons.insert_drive_file_outlined;
    }
  }

  static IconData get collectionsBookmark {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.collections_bookmark;
      case ApIcon.OUTLINED:
      default:
        return Icons.collections_bookmark_outlined;
    }
  }

  static IconData get accessibilityNew {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.accessibility_new;
      case ApIcon.OUTLINED:
      default:
        return Icons.accessibility_new;
    }
  }

  static IconData get monetizationOn {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.monetization_on;
      case ApIcon.OUTLINED:
      default:
        return Icons.monetization_on_outlined;
    }
  }

  static IconData get map {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.map;
      case ApIcon.OUTLINED:
      default:
        return Icons.map_outlined;
    }
  }

  static IconData get navigation {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.navigation;
      case ApIcon.OUTLINED:
      default:
        return Icons.navigation_outlined;
    }
  }

  static IconData get room {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.room;
      case ApIcon.OUTLINED:
      default:
        return Icons.room_outlined;
    }
  }

  static IconData get home {
    switch (ApIcon.code) {
      case ApIcon.FILLED:
        return Icons.home;
      case ApIcon.OUTLINED:
      default:
        return Icons.home_outlined;
    }
  }
}
